import xfox
import discord
from Amisynth.utils import buttons

@xfox.addfunc(xfox.funcs)
async def addButton(new_row: str, button_id: str, label: str, style: str, *args, **kwargs):
    """Crea múltiples botones interactivos y devuelve una lista de objetos de botones creados."""
    
    # Estilos disponibles
    estilos = {
        "Primary": discord.ButtonStyle.primary,
        "Secondary": discord.ButtonStyle.secondary,
        "Success": discord.ButtonStyle.success,
        "Danger": discord.ButtonStyle.danger,
        "Link": discord.ButtonStyle.link
    }
    
    
    # Manejar múltiples botones
    for i in range(0, len(args), 3):  # Se asume que cada botón tiene 3 argumentos adicionales
        button_args = args[i:i+3]
        disabled = button_args[0].lower() == "true" if len(button_args) > 0 else False
        emoji = button_args[1] if len(button_args) > 1 else None
        message_id = button_args[2] if len(button_args) > 2 else None
        
        button_style = estilos.get(style, discord.ButtonStyle.primary)
        
        button = discord.ui.Button(
            label=label,
            custom_id=button_id if button_style != discord.ButtonStyle.link else None,
            style=button_style,
            emoji=emoji,
            disabled=disabled,
            url=button_id if button_style == discord.ButtonStyle.link else None
        )
        
        buttons.append(button)
    
    return ""



import xfox

@xfox.addfunc(xfox.funcs)
async def message(num, *args, **kwargs):
    # Filtrar kwargs para ignorar 'ctx_slash_env'
    filtered_kwargs = {k: v for k, v in kwargs.items() if k != "ctx_slash_env"}

    # Obtener el contexto adecuado
    ctx_message_env = kwargs.get("ctx_message_env")
    ctx_command = kwargs.get("ctx_command")

    if ctx_message_env:
        message_content = ctx_message_env.content  # Mensaje del evento
        palabras = message_content.split()  # Obtener palabras
    elif ctx_command:
        message_content = ctx_command.message.content  # Mensaje del comando
        palabras = message_content.split()[1:]  # Excluir el nombre del comando
        

    # Si se proporciona un número, tratarlo como índice de palabras
    if num.isdigit():
        index = int(num) - 1  # Ajuste para empezar en 1
        palabra = palabras[index] if 0 <= index < len(palabras) else ""

        # Si hay argumentos extra, buscar en kwargs si la palabra no existe
        if args:
            for clave in args:
                if clave in filtered_kwargs:
                    return palabra if palabra else filtered_kwargs[clave]
        
        return palabra
    
    # Si num no es número, asumir que es una clave de kwargs
    return filtered_kwargs.get(num, "")



from setuptools import setup, find_packages

setup(
    name='amisynth',  # Nombre de tu paquete
    version='0.0.1',  # Versión de tu paquete
    packages=find_packages(),  # Encuentra todas las subcarpetas
    install_requires=["discord.py", "xfox"],  # Dependencias externas si las tienes
    description='Un paquete para integrar funciones personalizadas en Discord',  # Descripción de tu paquete
    long_description=open('README.md').read(),  # Leer README para información extra
    long_description_content_type='text/markdown',
    author='Amisinth',
    author_email='amisynth@gmail.com',  # Tu correo real
    url='https://github.com/tu_usuario/amisynth',  # Enlace a tu repositorio real
    classifiers=[  # Clasificadores para PyPI
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',  # Versión de Python mínima
)



import xfox
from Amisynth.utils import embeds

@xfox.addfunc(xfox.funcs)
async def description(texto: str, indice: int = 1, *args, **kwargs):
    """
    Guarda una descripción en la lista de embeds, con un índice opcional.
    Si se especifica el índice, se inserta o actualiza en esa posición. Si no, se agrega en la posición 1.
    
    :param texto: El texto de la descripción.
    :param indice: El índice opcional del embed (posición en la lista).
    """
    # Crear un embed con el texto de la descripción
    embed = {
        "description": texto,
        "index": indice  # Añadir el índice para identificar la posición
    }

    # Buscar si ya existe un embed con ese índice y actualizar solo la descripción
    for i, item in enumerate(embeds):
        if item.get("index") == indice:
            # Mantener los otros atributos del embed y solo actualizar la descripción
            embeds[i]["description"] = texto
            break
    else:
        # Si no se encontró, agregar uno nuevo
        embeds.append(embed)

    return ""
